# This file was auto-generated by Fern from our API Definition.

from .lab_tests_get_orders_request_order_direction import LabTestsGetOrdersRequestOrderDirection
from .lab_tests_get_orders_request_order_key import LabTestsGetOrdersRequestOrderKey

__all__ = ["LabTestsGetOrdersRequestOrderDirection", "LabTestsGetOrdersRequestOrderKey"]
