# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .client_facing_provider import ClientFacingProvider
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProfileInDb(UniversalBaseModel):
    data: typing.Optional[typing.Any] = None
    user_id: str
    source_id: int
    priority_id: typing.Optional[int] = None
    id: str
    source: ClientFacingProvider
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
