# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DelegatedFlowType(str, enum.Enum):
    ORDER_AND_RESULTS_WITH_CUSTOMER_PHYSICIAN_NETWORK = "order_and_results_with_customer_physician_network"
    ORDER_WITH_VITAL_PHYSICIAN_NETWORK = "order_with_vital_physician_network"
    ORDER_AND_RESULTS_WITH_VITAL_PHYSICIAN_NETWORK = "order_and_results_with_vital_physician_network"

    def visit(
        self,
        order_and_results_with_customer_physician_network: typing.Callable[[], T_Result],
        order_with_vital_physician_network: typing.Callable[[], T_Result],
        order_and_results_with_vital_physician_network: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is DelegatedFlowType.ORDER_AND_RESULTS_WITH_CUSTOMER_PHYSICIAN_NETWORK:
            return order_and_results_with_customer_physician_network()
        if self is DelegatedFlowType.ORDER_WITH_VITAL_PHYSICIAN_NETWORK:
            return order_with_vital_physician_network()
        if self is DelegatedFlowType.ORDER_AND_RESULTS_WITH_VITAL_PHYSICIAN_NETWORK:
            return order_and_results_with_vital_physician_network()
