# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ResultType(str, enum.Enum):
    NUMERIC = "numeric"
    RANGE = "range"
    COMMENT = "comment"

    def visit(
        self,
        numeric: typing.Callable[[], T_Result],
        range: typing.Callable[[], T_Result],
        comment: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ResultType.NUMERIC:
            return numeric()
        if self is ResultType.RANGE:
            return range()
        if self is ResultType.COMMENT:
            return comment()
